@@ -1,5 +1,5 @@
 /*
-@version: 0.3
+@version: 0.4
 @author: Aymeric Brisse <aymeric.brisse@gmail.com>
 @license: GNU General Public License
 */
@@ -8,28 +8,32 @@
 #define MAINWINDOW_H
 
 #include <QMainWindow>
+#include <QMessageBox>
 
 namespace Ui {
-    class MainWindow;
+  class MainWindow;
 }
 
 class MainWindow : public QMainWindow {
-    Q_OBJECT
+  Q_OBJECT
 public:
-    MainWindow(QWidget *parent = 0);
-    ~MainWindow();
+  MainWindow(QWidget *parent = 0);
+  ~MainWindow();
 
 protected:
-    void changeEvent(QEvent *e);
-    void loadValues();
+  void changeEvent(QEvent *e);
+  void loadValues();
+  void saveValues();
+  void about();
 
 private:
-    Ui::MainWindow *ui;
+  Ui::MainWindow *ui;
 
 
 
 private slots:
-    void on_btnSave_clicked();
+  void on_btnAbout_clicked();
+  void on_btnSave_clicked();
 };
 
 #endif // MAINWINDOW_H
